==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_computes_list/main.tf <==
/*
Пример использования
Получение списка computes, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_computes_list" "acl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 1111

  #id компьюта
  #опциональный параметр
  #тип - целое число
  #compute_id = 1234

  #имя аккаунта
  #опциональный параметр
  #тип - строка
  #name = "user1"

  #имя ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "rg_test"

  #id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 1111

  #технический статус
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #ip адрес
  #опциональный параметр
  #тип - строка
  #ip_address = "1.2.3.4"

  #имя внешней сети
  #опциональный параметр
  #тип - строка
  #extnet_name = "extnet_test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #id внешней сети
  #опциональный параметр
  #тип - целое число
  #extnet_id = 1

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_account_computes_list.acl
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/account/data_account_computes_list/main.tf <==
/*
Пример использования
Получение списка computes, используемых аккаунтом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_account_computes_list" "acl" {
  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 1111

  #id компьюта
  #опциональный параметр
  #тип - целое число
  #compute_id = 1234

  #имя аккаунта
  #опциональный параметр
  #тип - строка
  #name = "user1"

  #имя ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "rg_test"

  #id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 1111

  #технический статус
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #ip адрес
  #опциональный параметр
  #тип - строка
  #ip_address = "1.2.3.4"

  #имя внешней сети
  #опциональный параметр
  #тип - строка
  #extnet_name = "extnet_test"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #id внешней сети
  #опциональный параметр
  #тип - целое число
  #extnet_id = 1

  #номер страницы для отображения
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.dynamix_account_computes_list.acl
}
